# WARNING: This package is synced with FC
# Extract Mageia Linux name and version
%define distro_version	%(perl -ne '/^([.\\w\\s]+) \\(.+\\).+/ and print $1' < /etc/release)

# To bootstrap for example py3.x -> py3.y upgrades
%bcond_without python

# rpmbuild parameters:
# --with testsuite: Run the testsuite (biarch if possible).  Default is without.
# --with buildisa: Use %%{?_isa} for BuildRequires
# --with asan: gcc -fsanitize=address
# --without python: No python support.
# --with profile: gcc -fprofile-generate / -fprofile-use: Before better
#                 workload gets run it decreases the general performance now.
# --define 'scl somepkgname': Independent packages by scl-utils-build.
# --define 'tests "TEST1 ... TESTN": Limit testing to specified tests.

# Turn off the brp-python-bytecompile automagic
%global _python_bytecompile_extra 0

# Disable LTO until upstream fixes GDB's ODR woes.
%define _lto_cflags %{nil}

%{?scl:%scl_package gdb}
%{!?scl:
 %global pkg_name %{name}
 %global _root_prefix %{_prefix}
 %global _root_datadir %{_datadir}
 %global _root_libdir %{_libdir}
}

# If we're on Fedora or RHEL 9+, we will build the gdb-minimal package.
# Never build the -minimal package on SCLs, since it's unneeded there.
%if 0%{?fedora} || (0%{?rhel} > 8 && 0%{!?scl:1})
  %global _build_minimal 1
%elif 0%{?mageia:1}
  %global _build_minimal 1
%endif

# Include support for Guile? This is enabled on RHEL 8 and
# Fedora < 38.
%if (0%{?fedora:1} && 0%{?fedora} < 38) || (0%{?rhel:1} && 0%{?rhel} == 8)
  %define use_guile 1
%endif

Name: %{?scl_prefix}gdb

# Freeze it when GDB gets branched
%global snapsrc    20220501
# See timestamp of source gnulib installed into gnulib/ .
%global snapgnulib 20220501
%global tarname gdb-%{version}
Version: 16.2

# The release always contains a leading reserved number, start it at 1.
# `upstream' is not a part of `name' to stay fully rpm dependencies compatible for the testing.
Release: %mkrel 3

License: GPL-3.0-or-later AND BSD-3-Clause AND FSFAP AND LGPL-2.1-or-later AND GPL-2.0-or-later AND LGPL-2.0-or-later AND LicenseRef-Fedora-Public-Domain AND GFDL-1.3-or-later AND LGPL-2.0-or-later WITH GCC-exception-2.0 AND GPL-3.0-or-later WITH GCC-exception-3.1 AND GPL-2.0-or-later WITH GNU-compiler-exception
Group:   Development/Tools
# Do not provide URL for snapshots as the file lasts there only for 2 days.
# https://sourceware.org/pub/gdb/releases/FIXME{tarname}.tar.xz
Source: https://sourceware.org/pub/gdb/releases/%{tarname}.tar.xz
URL: https://gnu.org/software/gdb/

# For our convenience
%global gdb_src %{tarname}
%global gdb_build build-%{_target_platform}
%if 0%{?_build_minimal}
  %global gdb_build_minimal %{gdb_build}-minimal
%endif

# error: Installed (but unpackaged) file(s) found: /usr/lib/debug/usr/bin/gdb-gdb.py
# https://lists.fedoraproject.org/archives/list/devel@lists.fedoraproject.org/message/PBOJDOFMWTRV3ZOKNV5HN7IBX5EPHDHF/
%undefine _debuginfo_subpackages

# Recommend an implementation of /usr/bin/debuginfo-install
## (ngompa): We do not need this in build environments, only user environments
Recommends: pkg-command(debuginfo-install)

Summary: A GNU source-level debugger for C, C++, Fortran, Go and other languages
Requires: gdb-headless%{?_isa} = %{version}-%{release}

%description
GDB, the GNU debugger, allows you to debug programs written in C, C++,
Fortran, Go, and other languages, by executing them in a controlled
fashion and printing their data.

If you want to use GDB for development purposes, you should install
the 'gdb' package which will install 'gdb-headless' and possibly other
useful packages too.

%package headless

# gdb-add-index also uses 'readelf' and 'objcopy', both of which are
# in the binutils package.  (BZ 2275274)
Requires: binutils

Summary: A GNU source-level debugger for C, C++, Fortran, Go and other languages
Group:   Development/Tools

%ifarch %{arm} riscv64
  %global have_inproctrace 0
%else
  %global have_inproctrace 1
%endif

# https://fedorahosted.org/fpc/ticket/43 https://fedorahosted.org/fpc/ticket/109
Provides: bundled(libiberty) = %{snapsrc}
Provides: bundled(gnulib) = %{snapgnulib}
# The libraries in the top-level directory (libbfd, libopcodes,
# libctf) are covered by the "bundled(binutils)" below.  See ticket
# #109, as mentioned above.
Provides: bundled(binutils) = %{snapsrc}
# https://fedorahosted.org/fpc/ticket/130
Provides: bundled(md5-gcc) = %{snapsrc}

# https://fedoraproject.org/wiki/Packaging:Guidelines#BuildRequires_and_.25.7B_isa.7D
%if 0%{?_with_buildisa:1} || 0%{?_with_testsuite:1}
  %global buildisa %{?_isa}
%else
  %global buildisa %{nil}
%endif

%if 0%{!?mageia:1}
# https://bugzilla.redhat.com/show_bug.cgi?id=1209492
Recommends: default-yama-scope
%endif

# rpm-suggestions.py needs to import rpm which is found in python3-rpm.
Recommends: python3-rpm

BuildRequires: gcc-c++

# GDB patches have the format `gdb-<version>-bz<red-hat-bz-#>-<desc>.patch'.
# They should be created using patch level 1: diff -up ./gdb (or gdb-6.3/gdb).

#=
#push=Should be pushed upstream.
#fedora=Should stay as a Fedora patch.
#fedoratest=Keep it in Fedora only as a regression test safety.

# Cleanup any leftover testsuite processes as it may stuck mock(1) builds.
#=push+jan
Source2: gdb-orphanripper.c

# /etc/gdbinit (from Debian but with Fedora compliant location).
#=fedora
Source4: gdbinit

# Include the auto-generated file containing the "Patch:" directives.
# See README.local-patches for more details.
Source9998: _gdb.spec.Patch.include
Source9999: _gdb.spec.patch.include
%include %{SOURCE9998}

# Mageia patches:
Patch10000: gdb-16.2-buildid-locate-mageia.patch
Patch10001: fix-build-with-autoconf-2.69+.patch
Patch10002: gdb-autoconf.patch

# https://svnweb.mageia.org/soft/rpm/debuginfo-install/trunk/debuginfo-install
Source1000: debuginfo-install

BuildRequires: readline-devel%{buildisa} >= 7.0
BuildRequires: ncurses-devel%{buildisa} texinfo gettext flex bison
BuildRequires: expat-devel%{buildisa}
# gdb/minidebug.c uses the xz library to handle compressed debuginfo.
BuildRequires: xz-devel%{buildisa}
# dlopen() no longer makes rpm-libsFIXME{?_isa} (it's .so) a mandatory dependency.
BuildRequires: rpm-devel%{buildisa}
BuildRequires: zlib-devel%{buildisa} libselinux-devel%{buildisa}
%if 0%{?with_python:1}
  %global __python %{__python3}
BuildRequires: python3-devel%{buildisa}
%endif
# gdb-doc in PDF, see: https://bugzilla.redhat.com/show_bug.cgi?id=919891#c10
BuildRequires: texinfo-tex
%if 0%{?mageia:1}
BuildRequires: texlive
%else
BuildRequires: texlive-collection-latexrecommended
# Permit rebuilding *.[0-9] files even if they are distributed in gdb-*.tar:
BuildRequires: /usr/bin/pod2man
%endif
BuildRequires: libbabeltrace-devel%{buildisa}
%if %{defined use_guile}
    %if 0%{!?rhel:1}
BuildRequires: guile22-devel%{buildisa}
    %endif
    # Guile is only supported prior to RHEL9, where it was called "guile".
    %if 0%{?rhel:1} && 0%{?rhel} < 9
BuildRequires: guile-devel%{buildisa}
    %endif
%endif

# Add support for Intel Processor Trace on eligible architectures.
%global have_libipt 0
%ifarch %{ix86} x86_64
%global have_libipt 1
BuildRequires: libipt-devel%{buildisa}
%endif

# See https://bugzilla.redhat.com/show_bug.cgi?id=1593280
# DTS RHEL-6 has mpfr-2 while GDB requires mpfr-3 on RHEL-7, RHEL-8, and
# Fedora < 32, and mpfr-4 on Fedora 32+ and RHEL-9+.
BuildRequires: mpfr-devel%{buildisa}
BuildRequires: source-highlight-devel
%if 0%{!?rhel:1}
BuildRequires: xxhash-devel
%endif

# Include debuginfod support.
%if 0%{?mageia:1}
BuildRequires: elfutils-libdebuginfod-devel
%else
BuildRequires: elfutils-debuginfod-client-devel
%endif

# Workaround for missing boost-devel dependency (rhbz 1718480)
BuildRequires: boost-devel

%if 0%{?_with_testsuite:1}

# Ensure the devel libraries are installed for both multilib arches.
%global bits_local %{?_isa}
%global bits_other %{?_isa}
%ifarch ppc
  %global bits_other (%{__isa_name}-64)
%endif

%if 0%{!?mageia:1}
%ifarch ppc64 x86_64
  %global bits_other (%{__isa_name}-32)
%endif
%endif

BuildRequires: sharutils dejagnu

# Test supported SCL toolchain components.
BuildRequires: %{?scl_testing_prefix}gcc %{?scl_testing_prefix}gcc-c++ %{?scl_testing_prefix}gcc-gfortran

# Fedora supports Objective C.
%if 0%{!?rhel:1}
BuildRequires: gcc-objc
%elif 0%{?mageia:1}
BuildRequires: gcc-objc
%endif

# We don't support gcc-gdb-plugin on RHEL anymore.
%if 0%{!?rhel:1} && 0%{!?mageia:1}
BuildRequires: gcc-gdb-plugin%{?_isa}
%else
BuildRequires: gcc-plugins
%endif

BuildRequires: systemtap-sdt-devel
BuildRequires: opencl-headers ocl-icd-devel%{bits_local} ocl-icd-devel%{bits_other}

%if 0%{!?rhel:1} && 0%{!?mageia:1}
BuildRequires: gcc-go
BuildRequires: libgo-devel%{bits_local} libgo-devel%{bits_other}
%endif

%if 0%{!?rhel:1}
  %ifnarch s390x
# Fedora s390x does not support fpc.
BuildRequires: fpc
  %endif
%endif

%if 0%{!?rhel:1} && 0%{!?mageia:1}
BuildRequires: gcc-gnat
BuildRequires: libgnat%{bits_local} libgnat%{bits_other}
%endif
BuildRequires: glibc-devel%{bits_local} glibc-devel%{bits_other}
BuildRequires: libgcc%{bits_local} libgcc%{bits_other}
BuildRequires: libgfortran%{bits_local} libgfortran%{bits_other}
# libstdc++-devel of matching bits is required only for g++ -static.
BuildRequires: libstdc++%{bits_local} libstdc++%{bits_other}
%ifarch %{ix86} x86_64
BuildRequires: libquadmath%{bits_local} libquadmath%{bits_other}
%endif
# multilib glibc-static is open Bug 488472:
%if 0%{?rhel:1}
BuildRequires: glibc-static%{bits_other}
%endif
BuildRequires: valgrind%{bits_local} valgrind%{bits_other}
BuildRequires: xz
BuildRequires: rust
BuildRequires: elfutils-debuginfod
%endif
# endif _with_testsuite
BuildRequires: make gmp-devel

%description headless
GDB, the GNU debugger, allows you to debug programs written in C, C++,
Java, and other languages, by executing them in a controlled fashion
and printing their data.

%if 0%{?_build_minimal}
%package minimal
Summary: A GNU source-level debugger for C, C++, Fortran, Go and other languages (minimal version)
# gdb-add-index is shared with gdb-headless and it must be from same version
Conflicts: %{name}-headless < %{version}-%{release}
Conflicts: %{name}-headless > %{version}-%{release}

%description minimal
GDB, the GNU debugger, allows you to debug programs written in C, C++,
Fortran, Go, and other languages, by executing them in a controlled
fashion and printing their data.

This package provides a minimal version of GDB, tailored to be used by
the Fedora buildroot.  It should probably not be used by end users.
%endif
# endif _build_minimal

%package gdbserver
Summary: A standalone server for GDB (the GNU source-level debugger)
Group:   Development/Tools

%description gdbserver
GDB, the GNU debugger, allows you to debug programs written in C, C++,
Fortran, Go, and other languages, by executing them in a controlled
fashion and printing their data.

This package provides a program that allows you to run GDB on a different
machine than the one which is running the program being debugged.

%package doc
Summary: Documentation for GDB (the GNU source-level debugger)
License: GFDL
Group: Documentation
BuildArch: noarch

%description doc
GDB, the GNU debugger, allows you to debug programs written in C, C++,
Java, and other languages, by executing them in a controlled fashion
and printing their data.

This package provides INFO, HTML and PDF user manual for GDB.

%package -n urpmi-debuginfo-install
Summary: debuginfo-install shim for urpmi
License: CC0
Group: System/Packaging
Conflicts: dnf-utils
# Generic provides to indicate what command it is, also provided by dnf-utils
Provides: pkg-command(debuginfo-install)
BuildArch: noarch

%description -n urpmi-debuginfo-install
This package provides /usr/bin/debuginfo-install for using with urpmi.

%prep
%setup -q -n %{gdb_src}

# Files have `# <number> <file>' statements breaking VPATH / find-debuginfo.sh .
(cd gdb;rm -fv $(perl -pe 's/\\\n/ /' <Makefile.in|sed -n 's/^YYFILES = //p'))

# *.info* is needlessly split in the distro tar; also it would not get used as
# we build in GDB_BUILD, just to be sure.
find -name "*.info*"|xargs rm -f

# Apply patches defined on _gdb.spec.Patch.include

# Include the auto-generated patch directives.
# See README.local-patches for more details.
%include %{SOURCE9999}

# Mga: add urpmi option
%patch -P 10000 -p1
%patch -P 10001 -p1
%patch -P 10002 -p1

# The above patches twiddle a .m4 file for configure, so update the affected
# configure files
for d in libiberty; do
pushd $d
  autoconf -f
popd
done

find -name "*.orig" | xargs rm -f
! find -name "*.rej" # Should not happen.

# In the past a distro name prefix was added to the version string in
# version.in.
#
# However, placing text at the start of version.in can cause problems;
# GDB will have a version string that starts with text rather than a
# number as is the case with upstream GDB, and for most (all?) other
# distros.
#
# GDB's version string is exposed to users as part of the Python API,
# and it is not uncommon for users to try and grok the version number
# from this string.  Having Fedora/RHEL GDB not start with the major
# version number can be unexpected, and might cause tools/script that
# work for other builds of GDB to fail with Fedora/RHEL GDB.
#
# So, we switched to use the more standard --with-pkgversion configure
# option.  This ensures the distro name is still included in the 'gdb
# --version' output, but the text is no longer part of the string
# exposed in the Python API.
#
# Unfortunately, for RHEL the dist_name macro is not defined.  At
# least not on RHEL 9 or earlier.  So, if dist_name is not defined,
# but the rhel macro is, then we use a hard-coded RHEL appropriate
# string.
#
# FIXME: It would be nice to rewrite this using elif, but this is not
# supported on older (pre 9) RHEL systems.

%if 0%{?dist_name:1}
  %global pkgversion_configure_flag --with-pkgversion=%{dist_name}
%else
  %if 0%{?mageia:1}
    %global pkgversion_configure_flag --with-pkgversion=Mageia Linux
  %endif

  %if 0%{?fedora:1}
    %global pkgversion_configure_flag --with-pkgversion=Fedora Linux
  %endif

  %if 0%{?rhel:1}
    %global pkgversion_configure_flag --with-pkgversion=Red Hat Enterprise Linux
  %endif
%endif

# Change the version that gets printed by GDB.  The 'version' here is
# usually the same as the original upstream version on which we are
# based.  The 'release' is new information we're adding and identifies
# the modifications we've made to upstream.
cat > gdb/version.in << _FOO
%{?version_prefix:%version_prefix }%{version}-%{release}
_FOO

# Remove the info and other generated files added by the FSF release
# process.
rm -f libdecnumber/gstdint.h
rm -f bfd/doc/*.info
rm -f bfd/doc/*.info-*
rm -f gdb/doc/*.info
rm -f gdb/doc/*.info-*

mv -f readline/readline/doc readline-doc
rm -rf readline/readline/*
mv -f readline-doc readline/readline/doc

rm -rf zlib texinfo

%build

# A set of common GDB configure flags, which are used for both minimal
# and non-minimal compilations.
COMMON_GDB_CONFIGURE_FLAGS="\
        --prefix=%{_prefix}                                     \
        --libdir=%{_libdir}                                     \
        --sysconfdir=%{_sysconfdir}                             \
        --mandir=%{_mandir}                                     \
        --infodir=%{_infodir}                                   \
        --with-gdb-datadir=%{_datadir}/gdb                      \
        --enable-gdb-build-warnings=,-Wno-unused,-Wno-deprecated-declarations,-Wno-unused-function,-Wno-stringop-overflow\
%ifarch %{ix86}
,-Wno-format-overflow\
%endif
        --enable-build-with-cxx                                 \
%ifnarch %{ix86} alpha ppc s390 s390x x86_64 ppc64 ppc64le %{arm} aarch64 riscv64
        --disable-werror                                        \
%else
        --enable-werror                                         \
%endif
        --with-separate-debug-dir=/usr/lib/debug                \
        --disable-sim                                           \
        --disable-rpath                                         \
        --without-stage1-ldflags                                \
        --disable-libmcheck                                     \
        --with-system-readline                                  \
        --without-libunwind                                     \
        --enable-64-bit-bfd                                     \
        --with-system-zlib                                      \
        --with-lzma                                             \
        --with-debuginfod                                       \
%if 0%{?rhel:1}
        --disable-libctf
%endif
"

# Identify the build directory with the version of gdb as well as the
# architecture, to allow for mutliple versions to be installed and
# built.
# Initially we're in the GDB_SRC directory.

for fprofile in %{?_with_profile:-fprofile} ""
do

# We will first build the minimal version of GDB.
%if 0%{?_build_minimal}
mkdir %{gdb_build_minimal}$fprofile
cd %{gdb_build_minimal}$fprofile

# The configure flags we will use when building gdb-minimal.
GDB_MINIMAL_CONFIGURE_FLAGS="\
    --without-babeltrace \
    --without-expat \
    --disable-tui \
    --without-python \
    --without-guile \
    --disable-inprocess-agent \
    --without-intel-pt \
    --disable-unit-tests \
    --disable-source-highlight"

# Populate CFLAGS, LDFLAGS, CC, CXX, etc.
%set_build_flags
CFLAGS="$CFLAGS %{?_with_asan:-fsanitize=address}"
LDFLAGS="$LDFLAGS %{?_with_asan:-fsanitize=address}"
CXXFLAGS="$CXXFLAGS %{?_with_asan:-fsanitize=address}"

# --htmldir and --pdfdir are not used as they are used from GDB_BUILD.
../configure                                                    \
        ${COMMON_GDB_CONFIGURE_FLAGS}                           \
        ${GDB_MINIMAL_CONFIGURE_FLAGS}                          \
%if 0%{?pkgversion_configure_flag:1}
        "%{pkgversion_configure_flag}"                          \
%endif
        --with-auto-load-dir='$debugdir:$datadir/auto-load%{?scl::%{_root_datadir}/gdb/auto-load}'      \
        --with-auto-load-safe-path='$debugdir:$datadir/auto-load%{?scl::%{_root_datadir}/gdb/auto-load}'        \
%if 0%{?mageia:1}
        --enable-targets=arm-linux-gnu,aarch64-linux-gnu,x86_64-mageia-linux-gnu     \
%else
        --enable-targets=s390-linux-gnu,powerpc-linux-gnu,arm-linux-gnu,aarch64-linux-gnu,riscv64-linux-gnu,x86_64-redhat-linux-gnu     \
%endif
        %{_target_platform}

# Prepare gdb/config.h first.
%make_build CFLAGS="$CFLAGS $FPROFILE_CFLAGS" LDFLAGS="$LDFLAGS $FPROFILE_CFLAGS" V=1 maybe-configure-gdb
perl -i.relocatable -pe 's/^(D\[".*_RELOCATABLE"\]=" )1(")$/${1}0$2/' gdb/config.status

%make_build CFLAGS="$CFLAGS $FPROFILE_CFLAGS" LDFLAGS="$LDFLAGS $FPROFILE_CFLAGS" V=1

cd ..
%endif
# endif _build_minimal

# Now we build the full GDB.
mkdir %{gdb_build}$fprofile
cd %{gdb_build}$fprofile

export CFLAGS="$RPM_OPT_FLAGS %{?_with_asan:-fsanitize=address} -DDNF_DEBUGINFO_INSTALL"
export LDFLAGS="%{?__global_ldflags} %{?_with_asan:-fsanitize=address}"
export CXXFLAGS="$CFLAGS"

# The configure flags we will use when building the full GDB.
GDB_FULL_CONFIGURE_FLAGS="\
        --with-system-gdbinit=%{_sysconfdir}/gdbinit            \
        --with-babeltrace                                       \
        --with-expat                                            \
$(: ppc64 host build crashes on ppc variant of libexpat.so )    \
        --without-libexpat-prefix                               \
        --enable-tui                                            \
%if 0%{?with_python:1}
        --with-python=%{__python}                               \
%else
        --without-python                                        \
%endif
%if %{defined use_guile}
        --with-guile                                            \
%else
        --without-guile                                         \
%endif
%if %{have_inproctrace}
        --enable-inprocess-agent                                \
%else
        --disable-inprocess-agent                               \
%endif
%if %{have_libipt}
        --with-intel-pt                                         \
%else
        --without-intel-pt                                      \
%endif
%if 0%{!?rhel:1}
        --with-xxhash                                           \
%endif
        --enable-unit-tests"

# --htmldir and --pdfdir are not used as they are used from GDB_BUILD.
../configure                                                    \
        ${COMMON_GDB_CONFIGURE_FLAGS}                           \
        ${GDB_FULL_CONFIGURE_FLAGS}                             \
%if 0%{?pkgversion_configure_flag:1}
        "%{pkgversion_configure_flag}"                          \
%endif
        --with-auto-load-dir='$debugdir:$datadir/auto-load%{?scl::%{_root_datadir}/gdb/auto-load}'      \
        --with-auto-load-safe-path='$debugdir:$datadir/auto-load%{?scl::%{_root_datadir}/gdb/auto-load}'        \
%if 0%{?mageia:1}
        --enable-targets=arm-linux-gnu,aarch64-linux-gnu,x86_64-mageia-linux-gnu     \
%else
        --enable-targets=s390-linux-gnu,powerpc-linux-gnu,arm-linux-gnu,aarch64-linux-gnu,riscv64-linux-gnu,x86_64-redhat-linux-gnu     \
%endif
        %{_target_platform}

if [ -z "%{!?_with_profile:no}" ]
then
  # Run all the configure tests being incompatible with $FPROFILE_CFLAGS.
  %make_build configure-host configure-target
  %make_build clean

  # Workaround -fprofile-use:
  # linux-x86-low.c:2225: Error: symbol `start_i386_goto' is already defined
  %make_build -C gdb/gdbserver linux-x86-low.o
fi

# Global CFLAGS would fail on:
# conftest.c:1:1: error: coverage mismatch for function 'main' while reading counter 'arcs'
if [ "$fprofile" = "-fprofile" ]
then
  FPROFILE_CFLAGS='-fprofile-generate'
elif [ -z "%{!?_with_profile:no}" ]
then
  FPROFILE_CFLAGS='-fprofile-use'
  # We cannot use -fprofile-dir as the bare filenames clash.
  (cd ../${builddir}-fprofile;
   # It was 333 on x86_64.
   test $(find -name "*.gcda"|wc -l) -gt 300
   find -name "*.gcda" | while read -r i
   do
     ln $i ../${builddir}/$i
   done
  )
else
  FPROFILE_CFLAGS=""
fi

# Prepare gdb/config.h first.
%make_build CFLAGS="$CFLAGS $FPROFILE_CFLAGS" LDFLAGS="$LDFLAGS $FPROFILE_CFLAGS" V=1 maybe-configure-gdb
perl -i.relocatable -pe 's/^(D\[".*_RELOCATABLE"\]=" )1(")$/${1}0$2/' gdb/config.status

%make_build CFLAGS="$CFLAGS $FPROFILE_CFLAGS" LDFLAGS="$LDFLAGS $FPROFILE_CFLAGS" V=1

! grep '_RELOCATABLE.*1' gdb/config.h

if [ "$fprofile" = "-fprofile" ]
then
  cd gdb
  cp -p gdb gdb-withindex
  PATH="$PWD:$PATH" sh ../../gdb/gdb-add-index $PWD/gdb-withindex
  ./gdb -nx -ex q ./gdb-withindex
  ./gdb -nx -readnow -ex q ./gdb-withindex
  cd ..
fi

cd ..

done  # fprofile

cd %{gdb_build}

%make_build \
     -C gdb/doc {gdb,annotate}{.info,/index.html,.pdf} MAKEHTMLFLAGS=--no-split MAKEINFOFLAGS=--no-split V=1

# Copy the <sourcetree>/gdb/NEWS file to the directory above it.
cp $RPM_BUILD_DIR/%{gdb_src}/gdb/NEWS $RPM_BUILD_DIR/%{gdb_src}

%check
# Initially we're in the GDB_SRC directory.
cd %{gdb_build}

# We always run the unittests.
(cd gdb; make run GDBFLAGS='-batch -ex "maintenance selftest"')

%if 0%{!?_with_testsuite:1}
echo ====================TESTSUITE DISABLED=========================
%else
echo ====================TESTING=========================
cd gdb
gcc -o ./orphanripper %{SOURCE2} -Wall -lutil -ggdb2
# Need to use a single --ignore option, second use overrides first.
# No `%{?_smp_mflags}' here as it may race.
# WARNING: can't generate a core file - core tests suppressed - check ulimit
# "readline-overflow.exp" - Testcase is broken, functionality is OK.
(
  # ULIMIT required for `gdb.base/auxv.exp'.
  ulimit -H -c
  ulimit -c unlimited || :

  # Setup $CHECK as `check//unix/' or `check//unix/-m64' for explicit bitsize.
  # Never use two different bitsizes as it fails on ppc64.
  echo 'int main (void) { return 0; }' >biarch.c
  CHECK=""
  for BI in -m64 -m32 -m31 ""
  do
    # Do not use size-less options if any of the sizes works.
    # On ia64 there is no -m64 flag while we must not leave a bare `check' here
    # as it would switch over some testing scripts to the backward compatibility
    # mode: when `make check' was executed from inside the testsuite/ directory.
    if [ -z "$BI" -a -n "$CHECK" ];then
      continue
    fi
    # Do not use $RPM_OPT_FLAGS as the other non-size options will not be used
    # in the real run of the testsuite.
    if ! gcc $BI -o biarch biarch.c
    then
      continue
    fi
    CHECK="$CHECK check//unix/$BI check//native-gdbserver/$BI check//native-extended-gdbserver/$BI"
  done
  # Do not try -m64 inferiors for -m32 GDB as it cannot handle inferiors larger
  # than itself.
  # s390 -m31 still uses the standard ELF32 binary format.
  gcc $RPM_OPT_FLAGS -o biarch biarch.c
  RPM_SIZE="$(file ./biarch|sed -n 's/^.*: ELF \(32\|64\)-bit .*$/\1/p')"
  if [ "$RPM_SIZE" != "64" ]
  then
    CHECK="$(echo " $CHECK "|sed 's#check//unix/-m64 check//native-gdbserver/-m64 check//native-extended-gdbserver/-m64# #')"
  fi

  # Disable some problematic testcases.
  # RUNTESTFLAGS='--ignore ...' is not used below as it gets separated by the
  # `check//...' target spawn and too much escaping there would be dense.
  for test in                           \
    gdb.base/readline-overflow.exp      \
    gdb.base/bigcore.exp                \
%if 0%{?rhel} < 7 
    gdb.base/gnu-debugdata.exp          \
    gdb.base/access-mem-running.exp     \
    gdb.threads/access-mem-running-thread-exit.exp \
%endif
  ; do
    mv -f ../../gdb/testsuite/$test ../gdb/testsuite/$test-DISABLED || :
  done

  # Run all the scheduled testsuite runs also in the PIE mode.
  # See also: gdb-runtest-pie-override.exp
  ###CHECK="$(echo $CHECK|sed 's#check//unix/[^ ]*#& &/-fPIC/-pie#g')"

TESTS=""
%if 0%{?tests:1}
  for test in %{tests}; do
    TESTS="${TESTS:+$TESTS }$test"
  done
%endif
  ./orphanripper make %{?_smp_mflags} -k $CHECK TESTS="$TESTS" || :
)
for t in sum log
do
  for file in testsuite*/gdb.$t
  do
    suffix="${file#testsuite}"
    suffix="${suffix%/gdb.$t}"
    ln $file gdb-%{_target_platform}$suffix.$t || :
  done
done
# `tar | bzip2 | uuencode' may have some piping problems in Brew.
tar cjf gdb-%{_target_platform}.tar.bz2 gdb-%{_target_platform}*.{sum,log}
uuencode gdb-%{_target_platform}.tar.bz2 gdb-%{_target_platform}.tar.bz2
cd ../..
echo ====================TESTING END=====================
%endif
# endif _testsuite

%install
# Initially we're in the GDB_SRC directory.
%if 0%{?_build_minimal}
cd %{gdb_build_minimal}
rm -rf $RPM_BUILD_ROOT

%make_install %{?_smp_mflags}

# Delete everything except the 'gdb' binary, and then rename it to
# 'gdb.minimal'.
rm -rfv $RPM_BUILD_ROOT%{_prefix}/{include,lib*,share}
rm -fv $RPM_BUILD_ROOT%{_bindir}/{gcore,gdbserver,gstack,gdb-add-index}
mv $RPM_BUILD_ROOT%{_bindir}/gdb $RPM_BUILD_ROOT%{_bindir}/gdb.minimal

cd ..
%endif
# endif _build_minimal

# Install the full build.

cd %{gdb_build}

# We must remove the $RPM_BUILD_ROOT directory ourselves if we're not
# building gdb-minimal.
%if 0%{!?_build_minimal}
rm -rf $RPM_BUILD_ROOT
%endif

%make_install %{?_smp_mflags}

mkdir -p $RPM_BUILD_ROOT%{_prefix}/libexec
mv -f $RPM_BUILD_ROOT%{_bindir}/gdb $RPM_BUILD_ROOT%{_prefix}/libexec/gdb
ln -s -r $RPM_BUILD_ROOT%{_prefix}/libexec/gdb  $RPM_BUILD_ROOT%{_bindir}/gdb

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/gdbinit.d
touch -r %{SOURCE4} $RPM_BUILD_ROOT%{_sysconfdir}/gdbinit.d
sed 's#%%{_sysconfdir}#%{_sysconfdir}#g' <%{SOURCE4} >$RPM_BUILD_ROOT%{_sysconfdir}/gdbinit
touch -r %{SOURCE4} $RPM_BUILD_ROOT%{_sysconfdir}/gdbinit

for i in `find $RPM_BUILD_ROOT%{_datadir}/gdb/python/gdb -name "*.py"`
do
  # Files could be also patched getting the current time.
  touch -r $RPM_BUILD_DIR/%{gdb_src}/gdb/version.in $i
done

%if 0%{?_enable_debug_packages:1} && 0%{?with_python:1}
mkdir -p $RPM_BUILD_ROOT/usr/lib/debug%{_bindir}
cp -p ./gdb/gdb-gdb.py $RPM_BUILD_ROOT/usr/lib/debug%{_bindir}/
for pyo in "" "-O";do
  # RHEL-5: AttributeError: 'module' object has no attribute 'compile_file'
  %{__python} $pyo -c 'import compileall, re, sys; sys.exit (not compileall.compile_dir("'"$RPM_BUILD_ROOT/usr/lib/debug%{_bindir}"'", 1, "'"/usr/lib/debug%{_bindir}"'"))'
done
%endif

# Compile python files
%if 0%{?with_python:1}
%py_byte_compile %{__python3} %{buildroot}%{_datadir}/gdb/python/gdb

# BZ 999645: /usr/share/gdb/auto-load/ needs filesystem symlinks
for i in $(echo bin lib $(basename %{_libdir}) sbin|tr ' ' '\n'|sort -u);do
  # mkdir to satisfy dangling symlinks build check.
  mkdir -p $RPM_BUILD_ROOT%{_datadir}/gdb/auto-load/%{_root_prefix}/$i
  ln -s $(echo %{_root_prefix}|sed 's#^/*##')/$i \
        $RPM_BUILD_ROOT%{_datadir}/gdb/auto-load/$i
done
for i in `find $RPM_BUILD_ROOT%{_datadir}/gdb -name "*.py"`; do
  # Files are installed by install(1) not preserving the timestamps.
  touch -r $RPM_BUILD_DIR/%{gdb_src}/gdb/version.in $i
done
%endif

# Create the folder where GDB expects to find custom JIT readers.
mkdir -p %{buildroot}%{_libdir}/gdb

install -Dpm 0775 %{SOURCE1000} %{buildroot}%{_bindir}

# Remove the files that are part of a gdb build but that are owned and
# provided by other packages.
# These are part of binutils

rm -rf $RPM_BUILD_ROOT%{_datadir}/locale/
rm -f $RPM_BUILD_ROOT%{_infodir}/bfd*
rm -f $RPM_BUILD_ROOT%{_infodir}/standard*
rm -f $RPM_BUILD_ROOT%{_infodir}/configure*
rm -f $RPM_BUILD_ROOT%{_infodir}/sframe-spec*
# Just exclude the header files in the top directory, and don't exclude
# the gdb/ directory, as it contains jit-reader.h.
rm -rf $RPM_BUILD_ROOT%{_includedir}/*.h
rm -rf $RPM_BUILD_ROOT/%{_libdir}/lib{bfd*,opcodes*,iberty*,ctf*,sframe*}

# pstack obsoletion

ln -s gstack.1 $RPM_BUILD_ROOT%{_mandir}/man1/pstack.1
ln -s gstack $RPM_BUILD_ROOT%{_bindir}/pstack

# Packaged GDB is not a cross-target one.
(cd $RPM_BUILD_ROOT%{_datadir}/gdb/syscalls
 rm -f mips*.xml
 rm -f sparc*.xml
%ifnarch x86_64
 rm -f amd64-linux.xml
%endif
%ifnarch %{ix86} x86_64
 rm -f i386-linux.xml
%endif
)

# Documentation only for development.
rm -f $RPM_BUILD_ROOT%{_infodir}/gdbint*
rm -f $RPM_BUILD_ROOT%{_infodir}/stabs*
rm -f $RPM_BUILD_ROOT%{_infodir}/ctf-spec*

# Delete this too because the dir file will be updated at rpm install time.
# We don't want a gdb specific one overwriting the system wide one.

rm -f $RPM_BUILD_ROOT%{_infodir}/dir

# These files are unrelated to Fedora Linux.
rm -f $RPM_BUILD_ROOT%{_datadir}/gdb/system-gdbinit/elinos.py
rm -f $RPM_BUILD_ROOT%{_datadir}/gdb/system-gdbinit/wrs-linux.py
rmdir $RPM_BUILD_ROOT%{_datadir}/gdb/system-gdbinit

%files
# File must begin with "/": {GFDL,COPYING3,COPYING,COPYING.LIB,COPYING3.LIB}
%license COPYING3 COPYING COPYING.LIB COPYING3.LIB
%doc README NEWS
%{_bindir}/gdb
%{_bindir}/gcore
%{_mandir}/*/gcore.1*
%{_bindir}/gstack
%{_mandir}/*/gstack.1*
%{_bindir}/pstack
%{_mandir}/*/pstack.1*
# Provide gdb/jit-reader.h so that users are able to write their own GDB JIT
# plugins.
%{_includedir}/gdb
# Export the folder where JIT readers should be placed.
%dir %{_libdir}/gdb
%files headless
%{_prefix}/libexec/gdb
%config(noreplace) %{_sysconfdir}/gdbinit
%{_mandir}/*/gdb.1*
%{_sysconfdir}/gdbinit.d
%{_mandir}/*/gdbinit.5*
%{_bindir}/gdb-add-index
%{_mandir}/*/gdb-add-index.1*
%{_datadir}/gdb

# don't include the files in include, they are part of binutils

%files -n urpmi-debuginfo-install
%{_bindir}/debuginfo-install

%if 0%{?_build_minimal}
%files minimal
%{_bindir}/gdb.minimal
%{_bindir}/gdb-add-index
%endif

%files gdbserver
%{_bindir}/gdbserver
%{_mandir}/*/gdbserver.1*
%if %{have_inproctrace}
%{_libdir}/libinproctrace.so
%endif


%files doc
%doc %{gdb_build}/gdb/doc/{gdb,annotate}.{html,pdf}
%{_infodir}/annotate.info*
%{_infodir}/gdb.info*


%changelog
* Fri Feb 28 2025 wally <wally> 16.2-3.mga10
+ Revision: 2153859
- rebuild for python3.13

* Fri Feb 21 2025 wally <wally> 16.2-2.mga10
+ Revision: 2150349
- build without python for now (to unbreak py3.13 update process)

* Fri Feb 21 2025 tv <tv> 16.2-1.mga10
+ Revision: 2150301
- Rebase to FSF GDB 16.2.

* Fri Feb 21 2025 neoclust <neoclust> 15.2-4.mga10
+ Revision: 2150216
- Rebuild without bootstrap mode
+ wally <wally>
- fix building without python

* Wed Feb 19 2025 neoclust <neoclust> 15.2-2.mga10
+ Revision: 2149509
- Rebuild without python for python 3.13 bootstrap

* Sun Nov 17 2024 wally <wally> 15.2-1.mga10
+ Revision: 2116922
- new version 15.2 (sync with Fedora)

* Sun Nov 03 2024 wally <wally> 14.2-3.mga10
+ Revision: 2112264
- rebuild with new libdebuginfod splitted out in elfutils 0.192

* Tue May 21 2024 daviddavid <daviddavid> 14.2-2.mga10
+ Revision: 2065685
- gdb-headless requires python3-rpm

* Fri Apr 26 2024 wally <wally> 14.2-1.mga10
+ Revision: 2061270
- new version 14.2 (sync with Fedora where appropriate)

* Tue Apr 09 2024 wally <wally> 13.2-7.mga10
+ Revision: 2056111
- basesystem rebuild for i686

* Fri Dec 29 2023 papoteur <papoteur> 13.2-6.mga10
+ Revision: 2024322
- rebuild for python 3.12

* Thu Dec 07 2023 wally <wally> 13.2-5.mga10
+ Revision: 2014744
- rebuild with py3.12

* Thu Dec 07 2023 wally <wally> 13.2-4.mga10
+ Revision: 2014387
- bootstrap build for py3.12 update to correct repo

* Thu Dec 07 2023 wally <wally> 13.2-3.mga10
+ Revision: 2014382
- bootstrap build for py3.12 update

* Sun Nov 26 2023 wally <wally> 13.2-2.mga10
+ Revision: 2009684
- rebuild for rpm 4.19.0 with soversion 10

* Mon Sep 25 2023 tv <tv> 13.2-1.mga10
+ Revision: 1990911
- Rebase to FSF GDB 13.2

* Wed Mar 15 2023 tv <tv> 13.1-7.mga10
+ Revision: 1949118
- Rebase to FSF GDB 13.1.

* Tue Mar 14 2023 tv <tv> 12.1-7.mga9
+ Revision: 1949037
- Remove obsolete patches:
  o gdb-rhbz1398387-tab-crash-test.patch as that test didn't work anymore
  o gdb-6.6-buildid-locate-rpm-scl.patch and gdb-bz601887-dwarf4-rh-test.patch
- Tweak gdb-6.6-buildid-locate-rpm.patch, rpmTag is replaced with rpmDbiTagVal.
- Backport upstream patch "gdb: call check_typedef at beginning of
  dwarf_expr_context::fetch_result".
  SILENR - Backport fix for problems associated with GCC 13's self-move warning.
- Backport replace deprecated distutils.sysconfig in python-config.
- Backport upstream commits 38665d717a3 and c3efaf0afd9 to fix crash with an
  internal error when generating a trace in drkonqi (rhbz#2152431)

* Thu Dec 22 2022 tv <tv> 12.1-6.mga9
+ Revision: 1925915
- Remove gdb-6.6-buildid-locate-rpm-scl.patch and
  gdb-bz601887-dwarf4-rh-test.patch.
- Remove gdb-fortran-frame-string.patch, a version of this test has now been upstreamed

* Fri Dec 09 2022 tv <tv> 12.1-5.mga9
+ Revision: 1919683
- Remove gdb-physname-pr11734-test.patch,
  gdb-physname-pr12273-test.patch, gdb-runtest-pie-override.patch,
  gdb-test-expr-cumulative-archer.patch.

* Mon Dec 05 2022 tv <tv> 12.1-4.mga9
+ Revision: 1918205
- Remove gdb-6.3-threaded-watchpoints2-20050225.patch.  The test in this
  patch is a tweaked version of upstream test gdb.threads/watchthreads.exp
  from 2004.  It doesn't actually test anything new.
- Remove gdb-rhbz1325795-framefilters-test.patch.  This test doesn't
  pass in the curret state, and the code that introduced the original
  problem has been changed beyong recognition at this point.
- Backport "libiberty: Fix C89-isms in configure tests" and do likewise in
  gdb-6.6-buildid-locate-rpm.patch.
- Remove gdb-6.3-inheritancetest-20050726.patch.  Upstream testcase
  gdb.cp/impl-this.exp tests the printing of an instance variable from
  an inherited class in the "print c" test.
- Drop gdb-6.3-test-movedir-20050125.patch

* Fri Oct 21 2022 tv <tv> 12.1-3.mga9
+ Revision: 1898159
- Backport fix to gdb.base/break-main-file-remove-fail.exp
  ([gdb/testsuite] Use prototype to call libc functions)

* Wed Oct 12 2022 tv <tv> 12.1-2.mga9
+ Revision: 1896568
- Backport upstream patch "Add support for readline 8.2"
- Fix missing separate debuginfo build-id suggestion not working (rhbz#2122947)
- BR gmp-devel

* Thu May 19 2022 tv <tv> 12.1-1.mga9
+ Revision: 1858923
- Rebase to FSF GDB 12.1

* Fri Feb 11 2022 tv <tv> 11.2-1.mga9
+ Revision: 1773035
- Rebase to FSF GDB 11.2.

* Sun Feb 06 2022 wally <wally> 11.1-6.mga9
+ Revision: 1771853
- enable python support again for python3.10
+ tv <tv>
- Sync patches with FC

* Sat Feb 05 2022 wally <wally> 11.1-5.mga9
+ Revision: 1771566
- rebuild without python support for upcoming python3.10 update

* Wed Jan 19 2022 tv <tv> 11.1-4.mga9
+ Revision: 1769024
- Remove gdb-6.3-inferior-notification-20050721.patch
  which adds problematic attach-32 test.

* Tue Jan 11 2022 tv <tv> 11.1-3.mga9
+ Revision: 1767998
- Backport upstream patch "[PR gdb/27026] CTRL-C is ignored
  when debug info is downloaded" (rhbz#2024875)
- Backport upstream patch "rework "set debuginfod" commands" (rhbz#2024875)
- Backport upstream patch "Fix unittest.exp failure due to 'set debuginfod' addition"
  (rhbz#2024875)
- Add -Wno-unused-function to --enable-gdb-build-warnings to prevent the build failure:
  "../../gdb/c-exp.y:3455:1: error: 'void c_print_token(FILE*, int, YYSTYPE)'
  defined but not used [-Werror=unused-function]"
- Backport upstream patch "gdb: add set/show commands for managing debuginfod"
- Backport upstream patch "gdb.texinfo: Expand documentation for debuginfod"

* Wed Jan 05 2022 tv <tv> 11.1-2.mga9
+ Revision: 1766911
- Use %%set_build_flags to populate all relevant build flags
- Backport upstream fix and test case for a dprintf bug (rhbz#2022177)
- Backport manpage update to be closer to -help (rhbz#853071)

* Mon Oct 18 2021 tv <tv> 11.1-1.mga9
+ Revision: 1752056
- Drop mga6 area conflicts
- Rebase to FSF GDB 11.1.
- Adjust build-id related patches.
- Drop backported patches which are no longer relevant.
- Backport upstream patch which papers over Fortran lexical analyzer
  bug (rhbz#2012976).
- Disable -Werror
- Backport test for (rhbz#1976887)
- Backport upstream patch which fixes internal-error: Unexpected
  type field location kind (rhbz#1976887)
- Backport "[gdb] Improve early exits for env var in debuginfod-support.c"
- Backport "[gdb/cli] Don't assert on empty string for core-file"

* Sat Aug 21 2021 tv <tv> 10.2-2.mga9
+ Revision: 1742103
- Provide 'gdb-minimal' package, usuefull for minimal chroot
- Adjust 'gdb-libexec-add-index.patch' for the gdb-minimal case.
- Remove s390-linux-gnu,powerpc-linux-gnu from targets

* Mon Jun 07 2021 tv <tv> 10.2-1.mga9
+ Revision: 1729986
- Rebase to FSF GDB 10.2.

* Fri May 14 2021 wally <wally> 10.1-11.mga9
+ Revision: 1722959
- rebuild for boost 1.76.0

* Thu Apr 01 2021 tv <tv> 10.1-10.mga9
+ Revision: 1712493
- Backport "Save/restore file offset while reading notes in core file"
  (rhbz#1931344)
- Don't check for stgit unless needed w/generate-git-repo-from-patches.sh.
- Fix ERRORs w/unsupported tests on native-gdbserver targets.
- Backport "Disable bracketed paste mode in GDB tests"
- Backport "Handle DW_TAG_type_unit in process_symtab_unit"
- Fix potential hang during gdbserver testing (rhbz#1941080)

* Sun Mar 14 2021 wally <wally> 10.1-9.mga9
+ Revision: 1702623
- disable bootstrap build and enable python support

* Sun Mar 14 2021 wally <wally> 10.1-8.mga9
+ Revision: 1702504
- bootstrap build without python support for new python 3.9

* Tue Mar 09 2021 tv <tv> 10.1-7.mga9
+ Revision: 1700856
- Fix for frame_id_p assertion failure (rhbz#1909902)

* Sun Feb 28 2021 tv <tv> 10.1-6.mga9
+ Revision: 1693266
- Fix aarch64 build problem (rhbz#1932645, Kevin Buettner).
- Fix gdb-vla-intel-fortran-vla-strings.patch for compatiblity with GraalVM.
- Fix gnulib related build problem (rhbz#1930528, Kevin Buettner).
- Fix libstdc++ assert when performing tab completion; build must be made
  with -D_GLIBCXX_DEBUG flag in order to trigger assert (rhbz#1912985,
  Kevin Buettner).

* Thu Dec 31 2020 wally <wally> 10.1-5.mga8
+ Revision: 1666757
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 10.1-4.mga8
+ Revision: 1661999
- rebuild for boost 1.74.0

* Fri Dec 11 2020 tv <tv> 10.1-3.mga8
+ Revision: 1655363
- Fix off-by-one error in ada_fold_name.patch (rhbz#1905996)

* Sat Nov 07 2020 wally <wally> 10.1-2.mga8
+ Revision: 1643505
- switch to guile3.0

* Fri Nov 06 2020 wally <wally> 10.1-1.mga8
+ Revision: 1643104
- workaround build issue with autoconf 2.69d
+ tv <tv>
- Rebase to FSF GDB 10.1.
- Bump 'snapgnulib' date.
- Drop merged patches
- Adjust build-id related patches.
- Ajust VLA patches.
+ pterjan <pterjan>
- Drop comment after %%endif, rpm now complains

* Mon Aug 10 2020 tv <tv> 9.2-1.mga8
+ Revision: 1613155
- 9.2
- Enable libxxhash during build
- Enable debuginfod support
- Sync patches with FC
- Fix build with autoconf 2.69+
- Fix build breakage when compiling bfd/elf.c with gcc 10 (rhbz#1818011)

* Sun May 03 2020 wally <wally> 9.1-3.mga8
+ Revision: 1578052
- rebuild for boost 1.73.0

* Mon Mar 16 2020 tv <tv> 9.1-2.mga8
+ Revision: 1556632
- re-enable guile support (in order to limit drakx changes)

* Tue Mar 03 2020 tv <tv> 9.1-1.mga8
+ Revision: 1553332
- 9.1

* Sun Jan 26 2020 wally <wally> 8.3.1-6.mga8
+ Revision: 1483367
- rebuild for boost 1.72.0

* Sat Jan 04 2020 luigiwalser <luigiwalser> 8.3.1-5.mga8
+ Revision: 1475948
- rebuild for readline
+ wally <wally>
- replace deprecated %%makeinstall_std

* Thu Dec 05 2019 tv <tv> 8.3.1-4.mga8
+ Revision: 1464676
- move recommends on debuginfo-install into gdb

* Thu Dec 05 2019 ngompa <ngompa> 8.3.1-3.mga8
+ Revision: 1464524
- Downgrade dependency on pkg-command(debuginfo-install) to Recommends

* Fri Oct 04 2019 tv <tv> 8.3.1-2.mga8
+ Revision: 1449203
- rebuild for new libipt

* Mon Sep 23 2019 tv <tv> 8.3.1-1.mga8
+ Revision: 1444913
- 8.3.1

* Fri Sep 20 2019 tmb <tmb> 8.3-5.mga8
+ Revision: 1444122
- PR gdb/25009:
  * Add --with-static-standard-libraries to the top level
  * Add Rust support to source highlighting
  * should fix gdb error: terminate called after throwing an instance
    of 'srchilite::ParserException', what():  error during the parsing
    of a definition file, core dumped.

* Thu Sep 19 2019 tv <tv> 8.3-4.mga8
+ Revision: 1443777
- rebuild for librpm9

* Tue Sep 03 2019 wally <wally> 8.3-3.mga8
+ Revision: 1436779
- rebuild for python3.8 support

* Tue Sep 03 2019 wally <wally> 8.3-2.mga8
+ Revision: 1436677
- build without python support to bootstrap python3.8

* Tue Jul 23 2019 tv <tv> 8.3-1.mga8
+ Revision: 1423532
- Release GDB 8.3.
- sync patches with FC
- BuildRequire on 'source-highlight-devel' and enable styled output.
- Disable temporarily guile support
- Use "--enable-unit-tests" flag when compiling GDB.
- Enable and always run the unittests when building the package.

* Sat May 11 2019 akien <akien> 8.2-8.mga7
+ Revision: 1397296
- Rebuild for bootstrapped i586 rust

* Fri Apr 05 2019 pterjan <pterjan> 8.2-7.mga7
+ Revision: 1385850
- Fix debuginfo-install now that debuginfo packages are per binary package

* Sat Jan 05 2019 wally <wally> 8.2-6.mga7
+ Revision: 1349290
- really enable python support again

* Sat Jan 05 2019 wally <wally> 8.2-5.mga7
+ Revision: 1349239
- enable python support again

* Fri Jan 04 2019 wally <wally> 8.2-4.mga7
+ Revision: 1349063
- build without python3 for python3.7 update

* Fri Dec 28 2018 tv <tv> 8.2-3.mga7
+ Revision: 1345366
- Fix 'py-bt is broken, results in exception' (rhbz#1639242)
- Fix 'GDB crashes when running from a deleted directory' (rhbz#1653410)

* Sat Oct 06 2018 pterjan <pterjan> 8.2-2.mga7
+ Revision: 1318196
- Fix BuildRequires

* Sat Oct 06 2018 tv <tv> 8.2-1.mga7
+ Revision: 1318179
- BR mpfr-devel
- FSF GDB 8.2
- rely on filetriggers for info system (mga#23482)
- Enable arm*, aarch64*, s390* & ppc* targets on all archs (rhbz#1011647 & #1056259)
  (--enable-targets= allows building a single GDB executable that supports
  multiple remote target architectures)
- rm -rf texinfo/ (rhbz#1562580)
+ pterjan <pterjan>
- Enable fpc back on aarch64 now that we have it
- Re-enable rust on aarch64
- Temporarily disable fpc and rust on aarch64 (fpc only supports aarch64 in trunk, and I haven't maanged to get rust to build yet)

* Wed Feb 07 2018 tv <tv> 8.1-2.mga7
+ Revision: 1199446
- Fix -D_GLIBCXX_DEBUG gdb-add-index regression (rhbz#1540559)

* Thu Feb 01 2018 tv <tv> 8.1-1.mga7
+ Revision: 1198435
- 8.1 final

* Sat Dec 30 2017 tv <tv> 8.0.50.20171213-1.mga7
+ Revision: 1187550
- Rebase to FSF GDB 8.0.50.20171213 (8.1pre).
- Implemented new method for dealing with FC patches.
- Convert all the patches to 'git-am' format.
- Remove merged CVE fix
- move CVE fix out of FC patches

* Fri Dec 29 2017 luigiwalser <luigiwalser> 8.0.1-4.mga7
+ Revision: 1187293
- add patch from ubuntu to fix part of CVE-2016-4491

* Mon Oct 30 2017 tv <tv> 8.0.1-3.mga7
+ Revision: 1174894
- Use inlined func name for printing breakpoints (RH BZ 1228556, Keith Seitz).

* Sun Oct 01 2017 tv <tv> 8.0.1-2.mga7
+ Revision: 1162089
- Performance fix of gcore to use --readnever (rhbz#1493675)

* Thu Sep 14 2017 tv <tv> 8.0.1-1.mga7
+ Revision: 1153805
- Rebase to FSF GDB 8.0.1 (8.0 stable branch)

* Tue Sep 05 2017 tv <tv> 8.0-6.mga7
+ Revision: 1151365
- fix build with rpm-4.14
- Two fixes from upstream stable branch 8.0.
- rebuild for rpm 4.14
- drop gcc-java BR
- sync patches with RH:
- Backport DWARF-5 and breakpoint fixes from upstream stable branch 8.0.
- Backport a fix for clang && -gsplit-dwarf debuggees (rhbz#1482892)

* Thu Aug 03 2017 philippem <philippem> 8.0-5.mga7
+ Revision: 1134400
- rebuild for Python 3.6

* Thu Jul 20 2017 tv <tv> 8.0-4.mga7
+ Revision: 1125539
- fix conflicts

* Tue Jul 18 2017 tv <tv> 8.0-3.mga7
+ Revision: 1124724
- we don't have rust on armv5

* Mon Jul 17 2017 tv <tv> 8.0-2.mga7
+ Revision: 1124517
- fix urpmi-debuginfo-install version by following gdb'sone
- split headless package (rhbz#1195005)
- new release
- sync patches with FC

* Fri Jul 07 2017 pterjan <pterjan> 7.12-16.mga6
+ Revision: 1109207
- Fix gdb --version

* Fri May 19 2017 akien <akien> 7.12-15.mga6
+ Revision: 1103447
- Fix broken backtrace on i586 (rhbz#1411094)

* Sun May 14 2017 ngompa <ngompa> 7.12-14.mga6
+ Revision: 1101002
- Have urpmi-debuginfo-install conflict with gdb with bundled debuginfo-install

* Sat May 06 2017 ngompa <ngompa> 7.12-13.mga6
+ Revision: 1099350
- Split bundled debuginfo-install script into subpackage
- Require any implementation of /usr/bin/debuginfo-install
- Adjust buildid-locate-mageia patch to offer dnf and urpmi suggestions

* Thu Oct 27 2016 tv <tv> 7.12-12.mga6
+ Revision: 1063735
- new relaese

* Wed Jun 08 2016 tv <tv> 7.11.1-12.mga6
+ Revision: 1020875
- rebase to released FSF GDB 7.11.1
- import bare DW_TAG_lexical_block (rhbz#1325396)

* Thu May 12 2016 tv <tv> 7.11-12.mga6
+ Revision: 1014009
- gdb does not work without python3

* Mon May 09 2016 tv <tv> 7.11-11.mga6
+ Revision: 1011790
- sync patches with FC

* Fri Apr 29 2016 tv <tv> 7.11-10.mga6
+ Revision: 1007742
- import upstream 7.11 branch stable fixes

* Thu Apr 14 2016 tv <tv> 7.11-9.mga6
+ Revision: 1001347
- reenable python bytecompiling
- regroup mga stuff at top
- BR gcc-java
- BR gcc-gfortran & gcc-objc
- BR gcc-plugins

* Thu Apr 14 2016 tv <tv> 7.11-8.mga6
+ Revision: 1001307
- fix one last python3 exception

* Thu Apr 14 2016 tv <tv> 7.11-7.mga6
+ Revision: 1001297
- switch to python3 (also fixing exception at startup)

* Thu Apr 14 2016 tv <tv> 7.11-6.mga6
+ Revision: 1001274
- recommends gcc-plugins
- BR fpc
- BR dejagnu
- split gdbserver & doc subpackages
- explicitely enable inproctrace on x86 only

* Thu Apr 14 2016 tv <tv> 7.11-5.mga6
+ Revision: 1001158
- disable libipt on !x86

* Wed Apr 13 2016 tv <tv> 7.11-4.mga6
+ Revision: 1001116
- enable libipt support

* Wed Apr 13 2016 tv <tv> 7.11-3.mga6
+ Revision: 1001080
- sync patches with FC

* Tue Mar 29 2016 tv <tv> 7.11-2.mga6
+ Revision: 996089
- sync patches with FC

* Sun Mar 06 2016 tv <tv> 7.11-1.mga6
+ Revision: 986574
- 7.11

* Sat Feb 20 2016 tv <tv> 7.10.90.20160216-1.mga6
+ Revision: 972394
- new snapshot

* Sun Jan 24 2016 tv <tv> 7.10.50.20160121-1.mga6
+ Revision: 926948
- new snapshot
- sync with FC
- new snapshot
- sync with FC
+ akien <akien>
- Disable Fedora-specific addition of dnf to the debuginfo-install command

* Sun Jan 24 2016 luigiwalser <luigiwalser> 7.10.50.20160106-3.mga6
+ Revision: 926912
- cloog-ppl is no longer used

* Sun Jan 17 2016 tv <tv> 7.10.50.20160106-2.mga6
+ Revision: 924820
- new snapshot
- sync with FC

* Wed Dec 02 2015 tv <tv> 7.10.50.20151113-1.mga6
+ Revision: 907792
- disable broken python byte compiling
- BR guile
- disable broken python byte compiling
- cleanups
- enable guile support
- drop %%with_system_readline option
- new release
- sync with FC
- notice that this package is synced with FC

* Thu Oct 08 2015 tv <tv> 7.10-4.mga6
+ Revision: 887255
- rebuild for python 3.5

* Mon Sep 21 2015 shlomif <shlomif> 7.10-3.mga6
+ Revision: 882116
- Rebuild + resumbit

* Sat Sep 05 2015 tv <tv> 7.10-2.mga6
+ Revision: 873130
- rebuild with new rpm

* Sun Aug 30 2015 tv <tv> 7.10-1.mga6
+ Revision: 871110
- submit to core/release
- new release

* Sun Aug 23 2015 tv <tv> 7.9.90.20150717-2.mga6
+ Revision: 868194
- rediff mga patch
- rebuild with rpm-4.13

* Sat Jul 25 2015 tv <tv> 7.9.90.20150717-1.mga6
+ Revision: 857603
- 7.9.90.20150717 (7.10 snapshot)

* Sun Jun 28 2015 tv <tv> 7.9.50.20150531-1.mga6
+ Revision: 846668
- new release

* Wed Nov 26 2014 tv <tv> 7.8.1-7.mga5
+ Revision: 799378
- sync patches with FC

* Fri Nov 21 2014 tv <tv> 7.8.1-6.mga5
+ Revision: 798197
- 7.8.1
- sync patches with FC

* Wed Oct 22 2014 tv <tv> 7.8-6.mga5
+ Revision: 792469
- sync patches with FC:
  o Accelerate interactive symbols lookup 15x.
  o Workaround makeinfo F-22 Bug 1154436.
  o Import 5 upstream gdb-7.8 branch fixes (async fix by Pedro Alves).
  o Fix 'Slow gstack performance' (RH BZ 1103894, Jan Kratochvil).
  o Fix "save breakpoints" for signal catchpoints and disabled breakpoints
    (BZ 1146170, Miroslav Franc).
  o Install gdb/jit-reader.h on include directory (BZ 1141968).
  o [testsuite] Fix runaway gdb.base/attach processes.
  o Fix GDB SIGTT* Stopped when using the PID argument (BZ 1136704, Pedro Alves).

* Wed Oct 15 2014 umeabot <umeabot> 7.8-5.mga5
+ Revision: 743932
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 7.8-4.mga5
+ Revision: 679456
- Mageia 5 Mass Rebuild

* Fri Aug 29 2014 tv <tv> 7.8-3.mga5
+ Revision: 669288
- sync patches with FC:
  o Fix babeltrace errors (Yao Qi)
  o Fix crash on Python frame filters with unreadable arg (rhbz#1126177)
  o Fix Python GIL with gdb.execute("continue") (Phil Muldoon, rhbz#1116957)

* Fri Aug 08 2014 tv <tv> 7.8-2.mga5
+ Revision: 661122
- sync with RH:
  o Enable babeltrace compile-time feature
  o Display Fortran strings in backtraces

* Thu Jul 31 2014 tv <tv> 7.8-1.mga5
+ Revision: 658489
- disable readline patch
- new release
- sync with FC
- adapt FC patches for final release

* Sun Jun 08 2014 tv <tv> 7.7.1-1.mga5
+ Revision: 634795
- do not build against system readline
- patch 10000: fix it so that it actually apply
- patch 10001: fix build with readline-6.3
- actually apply patch 10000
- sync patches with FC
- 7.7.1
- sync patches with FC

* Fri Feb 28 2014 tv <tv> 7.7-1.mga5
+ Revision: 598020
- rebase to FSF GDB 7.7
- sync patches with FC
- new rpmbuild option: --with asan

* Sat Oct 19 2013 umeabot <umeabot> 7.6-6.mga4
+ Revision: 531324
- Mageia 4 Mass Rebuild

* Sun Aug 04 2013 fwang <fwang> 7.6-5.mga4
+ Revision: 463108
- cleanup spec

* Wed Jun 12 2013 tv <tv> 7.6-4.mga4
+ Revision: 442021
- fix build with system readlien
- sync with FC
- link with system readline

* Tue May 28 2013 tv <tv> 7.6-3.mga4
+ Revision: 429541
- add latest patches from FC

* Tue May 28 2013 tv <tv> 7.6-2.mga4
+ Revision: 429494
- submit to core/release

* Mon May 27 2013 tv <tv> 7.6-1.mga4
+ Revision: 428980
- install pstack
- fix build
- adjust file list
- new release
- sync patches with FC

* Sun Apr 21 2013 tv <tv> 7.5.1-7.mga3
+ Revision: 410764
- further simplify patch 1000: Mageia have urpmi instead of yum
- Patch 10000: drop bits disabling debuginfo-install usage
- kill slow test
- do not make debuginfo-install uselessly slow
+ kamil <kamil>
- check if queried package is installed

* Sat Apr 20 2013 neoclust <neoclust> 7.5.1-6.mga3
+ Revision: 410634
- Make debuginfo-install executable

* Sun Apr 07 2013 neoclust <neoclust> 7.5.1-5.mga3
+ Revision: 408730
- Package debuginfo-install as a source of gdb ( mga #8555)

* Fri Jan 11 2013 umeabot <umeabot> 7.5.1-4.mga3
+ Revision: 351125
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 01 2013 tv <tv> 7.5.1-3.mga3
+ Revision: 337294
- simplify patch now that we've debuginfo (we now only miss debuginfo-install)

* Thu Dec 13 2012 tv <tv> 7.5.1-2.mga3
+ Revision: 330582
- merge patches from RH:
  o 'dwz -m' parsing fix
  o fix `GDB cannot access struct member whose offset is larger than 256MB'
    (RH BZ 871066)
  o fix DW_OP_GNU_implicit_pointer offset bug
- renumerate mga patches

* Sat Dec 01 2012 tv <tv> 7.5.1-1.mga3
+ Revision: 324015
- new release
- do apply some patches

* Sun Nov 18 2012 tv <tv> 7.5.0.20120926-1.mga3
+ Revision: 319509
- new snapshot (sync with FC)
+ fwang <fwang>
- update rpm group

* Sat Oct 06 2012 rtp <rtp> 7.5-2.mga3
+ Revision: 303021
- enable back sim and werror.

* Wed Aug 22 2012 tv <tv> 7.5-1.mga3
+ Revision: 283090
- new release
- sync patches with FC

* Mon Aug 13 2012 tv <tv> 7.4.91.20120801-1.mga3
+ Revision: 281165
- new release
- sync patches with FC

* Mon Jul 30 2012 tv <tv> 7.4.50.20120714-2.mga3
+ Revision: 276199
- enable lzma support for minidebuginfo

* Sun Jul 22 2012 shlomif <shlomif> 7.4.50.20120714-1.mga3
+ Revision: 273583
- New version 7.4.50.20120714 .
  Sync with the new upstream package. Many patches were updated and I also had
  to update the mageia patch for the debug info packages. This was done in
  order to make gdb build again and on the way to resolve bug #3417.

* Tue Dec 20 2011 dmorgan <dmorgan> 7.3.50.20110722-4.mga2
+ Revision: 185013
- Rebuild against rpm 4.9.1.2

* Thu Nov 24 2011 dmorgan <dmorgan> 7.3.50.20110722-3.mga2
+ Revision: 171528
- Resurect debug install helper patch ( mga #3417)

* Tue Oct 18 2011 dmorgan <dmorgan> 7.3.50.20110722-2.mga2
+ Revision: 156013
- Sync with fedora ==> Rebase to FSF GDB 7.3.50.20110722

* Tue Oct 11 2011 dmorgan <dmorgan> 7.1-7.mga2
+ Revision: 153808
- Adapt for rpm 4.9

* Tue Apr 05 2011 dmorgan <dmorgan> 7.1-6.mga1
+ Revision: 80703
- Specify used rpm lib
+ rtp <rtp>
- fix file list on arm/mips

* Mon Jan 17 2011 misc <misc> 7.1-5.mga1
+ Revision: 21081
- rebuild for python 2.7

* Tue Jan 11 2011 blino <blino> 7.1-4.mga1
+ Revision: 6533
- revert rpm5 patch
- do not hardcode distro name in macro
- update comment
- rename and adapt patch
- rename macro
- imported package gdb


* Sun Jan 09 2011 Per Øyvind Karlsen <peroyvind@mandriva.org> 7.1-4mdv2011.0
+ Revision: 630736
- fix python 2.7 support (P1001)

* Sat Dec 04 2010 Per Øyvind Karlsen <peroyvind@mandriva.org> 7.1-3mdv2011.0
+ Revision: 608927
- add versioned rpm-devel build requires
- port to rpm5 API (P1000)

* Sun Oct 31 2010 Funda Wang <fwang@mandriva.org> 7.1-2mdv2011.0
+ Revision: 590743
- rebuild for py2.7

* Fri Apr 16 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 7.1-1mdv2010.1
+ Revision: 535538
- Updated gdb to version 7.1
- Sync Fedora patches with gdb-7.1-12.fc13
- Update buildid-locate-mandriva patch for new gdb.

* Fri Jan 15 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 7.0.1-2mdv2010.1
+ Revision: 491836
- Make sure we always build with libexpat.

* Wed Jan 06 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 7.0.1-1mdv2010.1
+ Revision: 486873
- Sync fedora patches with 7.0.1-19.fc12

  + Emmanuel Andry <eandry@mandriva.org>
    - New version 7.0.1
    - drop p232 (merged upstream)
    - BR libcloog-devel

* Fri Dec 18 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 7.0-1mdv2010.1
+ Revision: 479987
- Rediff fix-sim-build, buildid-locate-mandriva.
- Sync patches with Fedora gdb package (7.0-9.fc12).

  + Christophe Fergeau <cfergeau@mandriva.com>
    - upload gdb 7.0 tarball (still not building :-/)
    - readd patches I didn't mean to remove just yet
    - update to first 7.0 prerelease, still not working because of autoconf issues :(
    - rediff patches against new gdb tarball
      add gdb-6.6-buildid-locate-rpm.patch from fedora (they split gdb-6.6-buildid-locate.patch in 2 separate patches)
      comment out 2 patches that haven't been rediffed yet
    - fix patch comment to be in line with fedora .spec comment
    - pick attach-signalled patch from fedora to replace ours
    - drop no longer useful patch (after switch to gcc 4.4?)
    - Patch179 has been dropped from RedHat too
    - sync RedHat patches to latest version
    - remove no longer used patches
    - patch backporting upstream fixes is no longer necessary
    - drop patches that are no longer in fedora package
    - use 6.8.50 CVS snapshot instead of the old 6.8 release
    - fix Patch176 (depended on an ia64 patch)
    - Patch112 is needed by Patch141, readd it
    - remove obsolete patches
    - drop unused patches
    - fix cvs snapshot handling
    - delete dropped patches
    - drop ppc, ia64 and sparc patches

  + Olivier Blin <oblin@mandriva.com>
    - add mips support (from Arnaud Patard)
    - fix a format error in sim-utils (from Arnaud Patard)

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 6.8-7mdv2010.0
+ Revision: 424577
- rebuild

* Mon Mar 23 2009 Paulo Andrade <pcpa@mandriva.com.br> 6.8-6mdv2009.1
+ Revision: 360759
- Correct #37755. See https://bugzilla.redhat.com/show_bug.cgi?id=453688#c3
  for more information. This basically allows 'valgrind --db-attach=yes' to
  work again, as this feature is missing since 2008.0. This patch is not
  fully correct as it depends on corrections in kernel code, but is enough
  to get gdb to stop at the proper moment memory corruption happened, and
  to allow checking contents of global and stack variables (of the current
  function, stack frame information is lost).

* Wed Jan 21 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6.8-5mdv2009.1
+ Revision: 332266
- Really fix display of missing debug packages (#47170).

* Wed Jan 21 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6.8-4mdv2009.1
+ Revision: 332195
- Fix display of missing debug packages (#47170).

* Tue Jan 20 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6.8-3mdv2009.1
+ Revision: 332036
- Reset _default_patch_fuzz to 2 until patches are rediffed.
- Updated buildid-locate patch from Fedora (reported by Pixel).
- Redid buildid-locate-mandriva patch.
- Rediffed rpm5-compat patch.

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - add rpm5.org compatibility (P319)

* Sun Aug 24 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6.8-2mdv2009.0
+ Revision: 275428
- Provide again gdbserver (#41257). For some unknown reason it was being
  removed on the spec, no explanation or changelog explaining this.

  + Götz Waschk <waschk@mandriva.org>
    - fix license

* Wed Jun 18 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6.8-1mdv2009.0
+ Revision: 224207
- Add BuildRequires for librpm-devel
- Mandriva doesn't have debuginfo-install etc., quick adapt for
  buildid-locate patch from Fedora (we should stop to share/sync all
  patches...)
- Updated to version 6.8
- Removed already applied patches:
  gdb-6.6-makeinfoversion.patch
  gdb-6.6-do-not-crash-on-line-info-with-no-file.patch
- Sync fedora patches with their latest gdb package (gdb-6.8-10.fc10).

* Tue Jun 17 2008 Thierry Vignaud <tv@mandriva.org> 6.6-6mdv2009.0
+ Revision: 221044
- rebuild

* Mon Mar 31 2008 Pixel <pixel@mandriva.com> 6.6-5mdv2008.1
+ Revision: 191243
- fixes gdb crashing when using kdelibs-debug (#29755)
  (without this patch, kcrash/drkonqi fails with a weird error message)

  + Frederic Crozat <fcrozat@mandriva.com>
    - Patch235 (CVS): fix rebuild with latest makeinfo

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Mon Sep 10 2007 Adam Williamson <awilliamson@mandriva.org> 6.6-3mdv2008.0
+ Revision: 84260
- rediff patch234 (spaces vs. tabs...)
- better version of patch234
- add patch234 suggested by blino to fix a warning which breaks %%configure
- don't package COPYING and COPYING.LIB
- drop menu entries (#27065)
- Fedora license policy, correct license
- drop old (10.1) conditionals

  + Oden Eriksson <oeriksson@mandriva.com>
    - sync with gdb-6.6-1mdv2007.1.src.rpm


* Sun Jan 28 2007 Per Øyvind Karlsen <pkarlsen@mandriva.com> 6.6-1mdv2007.0
+ Revision: 114460
- new release: 6.6
  sync with fedora
  fix prereq
- Import gdb

* Tue Sep 19 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 6.3-8mdv2007.0
- Rebuild

* Mon Jul 17 2006 Nicolas Lécureuil <neoclust@mandriva.org> 6.3-7mdv2007.0
- XDG

* Wed Oct 05 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 6.3-6mdk
- ppc64 fixes

* Mon Aug 01 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 6.3-5mdk
- add BuildRequires: bison

* Wed Jul 27 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 6.3-4mdk
- merge with RH 6.3.0.0-1.49

* Thu Jan 20 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 6.3-3mdk
- rebuild for new readline
- wipe out buildroot at the beginning of %%install

* Sun Nov 14 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 6.3-2mdk
- add BuildRequires: flex

* Wed Nov 10 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 6.3-1mdk
- 6.3

* Fri Aug 27 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 6.2-2mdk
- Improved i386 prologue analyzer from 6.2-branch (2004/07/08)

* Thu Aug 26 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 6.2-1mdk
- 6.2

* Sat Aug 14 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 6.1.1-2mdk
- Rebuild for new conversion table menu

* Sat Jul 31 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 6.1.1-1mdk
- package ppc-specific files
- 6.1.1

* Tue May 25 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 6.1-1mdk
- 6.1

